@@ -144,6 +144,8 @@ void initdb(bool readonly)
 					"Error opening db environment: %s (%s)",
 					config.db_dir,
 					db_strerror(ret));
+			dbenv->close(dbenv, 0);
+			dbenv = NULL;
 		}
 	}
 
@@ -270,6 +272,8 @@ void cleanupdb(void)
 				dbconns[i] = NULL;
 			}
 		}
+		free(dbconns);
+		dbconns = NULL;
 		dbenv->close(dbenv, 0);
 		dbenv = NULL;
 	}
